==> theia-0.1.8.1-py3-none-any.whl: theia/aws/storage/efs.py <==
import pulumi
from pulumi_aws import efs
from pydantic.dataclasses import dataclass, ConfigDict
from typing import Optional, List, Mapping, Literal

from theia import ResourceOptions
from theia.utils.logger import Logger
from theia._registry import StackRegistry, GlobalTags
from theia.definitions import THEIA_VERSION

logger = Logger("efs")


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class EFSTargetSettings:
    ip_address: Optional[str] = None
    security_groups: Optional[List[str]] = None
    subnet_id: Optional[str] = None 


@dataclass
class EFSFileSystemLifecyclePolicy:
    transition_to_ia: Optional[Literal["AFTER_1_DAY", "AFTER_7_DAYS", "AFTER_14_DAYS", "AFTER_30_DAYS", "AFTER_60_DAYS", "AFTER_90_DAYS"]] = None
    transition_to_primary_storage_class: Optional[Literal["AFTER_1_ACCESS"]] = None


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class EFSFileSystemSettings:
    availability_zone_name: Optional[str] = None
    creation_token: Optional[str] = None
    encrypted: Optional[bool] = None
    kms_key_id: Optional[str] = None
    lifecycle_policies: Optional[List[EFSFileSystemLifecyclePolicy]] = None
    performance_mode: Optional[Literal["generalPurpose", "maxIO"]] = "generalPurpose"
    provisioned_throughput_in_mibps: Optional[float] = None
    throughput_mode: Optional[Literal["bursting", "provisioned", "elastic"]] = "bursting"


class EFS():
    def __new__(
        cls,
        resource_name: str,
        file_system_settings: Optional[EFSFileSystemSettings] = EFSFileSystemSettings(),
        mount_target_settings: Optional[EFSTargetSettings] = None,
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> efs.FileSystemArgs:

        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        fs_lifecycle_policies = []
        if file_system_settings.lifecycle_policies:
            for rule in file_system_settings.lifecycle_policies:
                fs_lifecycle_policies.append(
                    efs.FileSystemLifecyclePolicyArgs(
                        transition_to_ia=rule.transition_to_ia,
                        transition_to_primary_storage_class=rule.transition_to_primary_storage_class
                    )
                )

        logger.info(f"creating EFS File System {resource_name}")

        file_system_args = efs.FileSystemArgs(
            availability_zone_name = file_system_settings.availability_zone_name,
            creation_token = file_system_settings.creation_token,
            encrypted = file_system_settings.encrypted,
            kms_key_id = file_system_settings.kms_key_id,
            lifecycle_policies = None if not file_system_settings.lifecycle_policies else fs_lifecycle_policies,
            performance_mode = file_system_settings.performance_mode,
            provisioned_throughput_in_mibps = file_system_settings.provisioned_throughput_in_mibps,
            throughput_mode = file_system_settings.throughput_mode,
            tags = merged_tags,
        )
        
        file_system_out=efs.FileSystem(
            resource_name=f"{resource_name}",
            args=file_system_args,
            opts=opts,
        )

        mounted_targets = []
        if mount_target_settings:
            for idx, target in enumerate(mount_target_settings):
                target_args = efs.MountTargetArgs(
                    file_system_id=file_system_out.id,
                    ip_address=target.ip_address,
                    security_groups=target.security_groups,
                    subnet_id=target.subnet_id,
                )

                target_out = efs.MountTarget(
                    resource_name=f"{resource_name}--mounted-target-{idx}",
                    args=target_args
                )

                mounted_targets.append({
                    "id": target_out.id
                })

        pulumi.export(
            f"efs-file-system---{resource_name}",
            {
                "id": file_system_out.id,
                "arn": file_system_out.arn,
                "mounted_targets": mounted_targets
            },
        )

        return file_system_out

    @staticmethod
    def import_(stack: str, resource_name: str) -> efs.FileSystem:
        stack_ref = StackRegistry.get(stack_name=stack)
        efs = stack_ref.get_output(name=f"efs-file-system---{resource_name}")
        return efs.FileSystem.get(resource_name=resource_name, id=EFS["id"])

==> theia-0.1.8.17-py3-none-any.whl: theia/aws/storage/efs.py <==
import pulumi
from pulumi_aws import efs
from pydantic.dataclasses import dataclass, ConfigDict
from typing import Optional, List, Mapping, Literal

from theia import ResourceOptions
from theia.utils.logger import Logger
from theia._registry import StackRegistry, GlobalTags
from theia.definitions import THEIA_VERSION

logger = Logger("efs")


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class EFSTargetSettings:
    ip_address: Optional[str] = None
    security_groups: Optional[List[str]] = None
    subnet_id: Optional[str] = None 


@dataclass
class EFSFileSystemLifecyclePolicy:
    transition_to_ia: Optional[Literal["AFTER_1_DAY", "AFTER_7_DAYS", "AFTER_14_DAYS", "AFTER_30_DAYS", "AFTER_60_DAYS", "AFTER_90_DAYS"]] = None
    transition_to_primary_storage_class: Optional[Literal["AFTER_1_ACCESS"]] = None


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class EFSFileSystemSettings:
    availability_zone_name: Optional[str] = None
    creation_token: Optional[str] = None
    encrypted: Optional[bool] = None
    kms_key_id: Optional[str] = None
    lifecycle_policies: Optional[List[EFSFileSystemLifecyclePolicy]] = None
    performance_mode: Optional[Literal["generalPurpose", "maxIO"]] = "generalPurpose"
    provisioned_throughput_in_mibps: Optional[float] = None
    throughput_mode: Optional[Literal["bursting", "provisioned", "elastic"]] = "bursting"


class EFS():
    def __new__(
        cls,
        resource_name: str,
        file_system_settings: Optional[EFSFileSystemSettings] = EFSFileSystemSettings(),
        mount_target_settings: Optional[List[EFSTargetSettings]] = None,
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> efs.FileSystemArgs:

        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        fs_lifecycle_policies = []
        if file_system_settings.lifecycle_policies:
            for rule in file_system_settings.lifecycle_policies:
                fs_lifecycle_policies.append(
                    efs.FileSystemLifecyclePolicyArgs(
                        transition_to_ia=rule.transition_to_ia,
                        transition_to_primary_storage_class=rule.transition_to_primary_storage_class
                    )
                )

        logger.info(f"creating EFS File System {resource_name}")

        file_system_args = efs.FileSystemArgs(
            availability_zone_name = file_system_settings.availability_zone_name,
            creation_token = file_system_settings.creation_token,
            encrypted = file_system_settings.encrypted,
            kms_key_id = file_system_settings.kms_key_id,
            lifecycle_policies = None if not file_system_settings.lifecycle_policies else fs_lifecycle_policies,
            performance_mode = file_system_settings.performance_mode,
            provisioned_throughput_in_mibps = file_system_settings.provisioned_throughput_in_mibps,
            throughput_mode = file_system_settings.throughput_mode,
            tags = merged_tags,
        )
        
        file_system_out=efs.FileSystem(
            resource_name=f"{resource_name}",
            args=file_system_args,
            opts=opts,
        )

        mounted_targets = []
        if mount_target_settings:
            for idx, target in enumerate(mount_target_settings):
                target_args = efs.MountTargetArgs(
                    file_system_id=file_system_out.id,
                    ip_address=target.ip_address,
                    security_groups=target.security_groups,
                    subnet_id=target.subnet_id,
                )

                target_out = efs.MountTarget(
                    resource_name=f"{resource_name}--mounted-target-{idx}",
                    args=target_args
                )

                mounted_targets.append({
                    "id": target_out.id
                })

        pulumi.export(
            f"efs-file-system---{resource_name}",
            {
                "id": file_system_out.id,
                "arn": file_system_out.arn,
                "mounted_targets": mounted_targets
            },
        )

        return file_system_out

    @staticmethod
    def import_(stack: str, resource_name: str) -> efs.FileSystem:
        stack_ref = StackRegistry.get(stack_name=stack)
        efs = stack_ref.get_output(name=f"efs-file-system---{resource_name}")
        return efs.FileSystem.get(resource_name=resource_name, id=EFS["id"])
